"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const push_1 = __importDefault(require("./push"));
const link_1 = __importDefault(require("../scripts/link"));
const Dependency_1 = __importDefault(require("../models/dependency/Dependency"));
const ProjectFile_1 = __importDefault(require("../models/files/ProjectFile"));
const prompt_1 = require("../prompts/prompt");
const naming_1 = require("../utils/naming");
const telemetry_1 = __importDefault(require("../telemetry"));
const name = 'link';
const signature = `${name} [dependencies...]`;
const description = 'links project with a list of dependencies each located in its npm package';
const register = program => program
    .command(signature, undefined, { noHelp: true })
    .usage('[dependencyName1 ... dependencyNameN] [options]')
    .description(description)
    .option('--no-install', 'skip installing packages dependencies locally')
    .withPushOptions()
    .withNonInteractiveOption()
    .action(action);
async function action(dependencies, options) {
    const { install, forceInstall, interactive } = options;
    const installDependencies = install || forceInstall;
    const args = { dependencies };
    const props = getCommandProps();
    const defaults = {
        dependencies: [await Dependency_1.default.fetchVersionFromNpm('@openzeppelin/contracts-ethereum-package')],
    };
    const prompted = await prompt_1.promptIfNeeded({ args, props, defaults }, interactive);
    const linkArguments = Object.assign(Object.assign({}, prompted), { installDependencies });
    if (!options.skipTelemetry)
        await telemetry_1.default.report('push', linkArguments, interactive);
    await link_1.default(linkArguments);
    await push_1.default.runActionIfRequested(Object.assign({}, options));
}
async function runActionIfNeeded(contractFullName, options) {
    const { interactive } = options;
    const projectFile = new ProjectFile_1.default();
    const { package: packageName } = naming_1.fromContractFullName(contractFullName);
    if (interactive && packageName && !projectFile.hasDependency(packageName)) {
        await action([packageName], Object.assign(Object.assign({}, options), { forceInstall: true, skipTelemetry: true }));
    }
}
function getCommandProps() {
    return {
        dependencies: {
            type: 'input',
            message: 'Provide an Ethereum Package name and version',
            normalize: input => (typeof input === 'string' ? [input] : input),
        },
    };
}
exports.default = {
    name,
    signature,
    description,
    register,
    action,
    runActionIfNeeded,
};
//# sourceMappingURL=link.js.map