"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const publish_1 = __importDefault(require("../scripts/publish"));
const ConfigManager_1 = __importDefault(require("../models/config/ConfigManager"));
const migrations_1 = require("../prompts/migrations");
const prompt_1 = require("../prompts/prompt");
const Session_1 = __importDefault(require("../models/network/Session"));
const telemetry_1 = __importDefault(require("../telemetry"));
const name = 'publish';
const signature = `${name}`;
const description = 'publishes your project to the selected network';
const register = program => program
    .command(signature, undefined, { noHelp: true })
    .usage('--network <network> [options]')
    .description(description)
    .withNetworkOptions()
    .withNonInteractiveOption()
    .action(action);
async function action(options) {
    const { network: networkInArgs, interactive } = options;
    const { network: networkInSession } = Session_1.default.getOptions();
    const defaults = { network: Session_1.default.getNetwork() };
    const opts = { network: networkInSession || networkInArgs };
    const props = getCommandProps();
    const promptedOpts = await prompt_1.promptIfNeeded({ opts, defaults, props }, interactive);
    const { network, txParams } = await ConfigManager_1.default.initNetworkConfiguration(promptedOpts);
    if (!(await migrations_1.hasToMigrateProject(network)))
        process.exit(0);
    await telemetry_1.default.report('publish', { network, txParams }, interactive);
    await publish_1.default({ network, txParams });
    if (!options.dontExitProcess && process.env.NODE_ENV !== 'test')
        process.exit(0);
}
function getCommandProps() {
    return prompt_1.networksList('network', 'list');
}
exports.default = { name, signature, description, register, action };
//# sourceMappingURL=publish.js.map