"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const stdout_1 = __importDefault(require("../utils/stdout"));
const NetworkController_1 = __importDefault(require("../models/network/NetworkController"));
const interfaces_1 = require("./interfaces");
const upgrades_1 = require("@newos/upgrades");
const input_1 = require("../utils/input");
async function createProxy({ packageName, contractName, methodName, methodArgs, network, txParams = {}, force = false, salt = null, signature = null, admin = null, kind = interfaces_1.ProxyType.Upgradeable, networkFile, }) {
    if (!contractName)
        throw Error('A contract name must be provided to create a new proxy.');
    input_1.validateSalt(salt, false);
    const controller = new NetworkController_1.default(network, txParams, networkFile);
    try {
        await controller.logErrorIfContractPackageIsInvalid(packageName, contractName, !force);
        const proxy = await controller.createProxy(packageName, contractName, methodName, methodArgs, kind, admin, salt, signature);
        upgrades_1.Loggy.noSpin(__filename, 'deploy', 'deploy-hint', `To upgrade this instance run 'newos upgrade'`);
        stdout_1.default(proxy.address);
        return proxy;
    }
    finally {
        controller.writeNetworkPackageIfNeeded();
    }
}
exports.default = createProxy;
//# sourceMappingURL=create.js.map